@@ -12,7 +12,8 @@ dumpA = setRV attr
 
 play vt x y sx sy btl = do update vt (render x y sx sy btl)
                            k <- getEvent vt
-                           case k of EvKey KLeft  [] | x /= 0      -> play vt (x-1) y sx sy btl
+                           case k of EvKey (KASCII 'r') [MCtrl]    -> refresh vt >> play vt x y sx sy btl
+                                     EvKey KLeft  [] | x /= 0      -> play vt (x-1) y sx sy btl
                                      EvKey KRight [] | x /= (sx-1) -> play vt (x+1) y sx sy btl
                                      EvKey KUp    [] | y /= 0      -> play vt x (y-1) sx sy btl
                                      EvKey KDown  [] | y /= (sy-2) -> play vt x (y+1) sx sy btl
